// Megumin top

#include <algorithm>
#include <iostream>
#include <vector>
#include <string>
#include <set>
#include <map>

using namespace std;

typedef int ll;
typedef long double ld;
typedef struct Node* pNode;

inline void start() {
	ios_base::sync_with_stdio(false);
	cout.tie(nullptr);
	cin.tie(nullptr);
}

struct Question {
	ll left, right, index;

	Question(ll left, ll right, ll index)
		: left(left), right(right), index(index) {}
};

struct Node {
	vector<ll> value;
	ll left, right;
	pNode child_left, child_right;

	Node(ll left, ll right)
		: left(left), right(right) {
		child_left = child_right = nullptr;
		value.resize(right - left);
	}
};

inline void merge(vector<ll>& a, vector<ll>& b, vector<ll>& res) {
	ll ptr1 = 0;
	ll ptr2 = 0;
	while (ptr1 < a.size() && ptr2 < b.size()) {
		if (a[ptr1] < b[ptr2]) {
			res[ptr1 + ptr2] = b[ptr2];
			++ptr2;
		}
		else {
			res[ptr1 + ptr2] = a[ptr1];
			++ptr1;
		}
	}
	while (ptr1 < a.size()) {
		res[ptr1 + ptr2] = a[ptr1];
		++ptr1;
	}
	while (ptr2 < b.size()) {
		res[ptr1 + ptr2] = b[ptr2];
		++ptr2;
	}
}

pNode build(ll left, ll right, vector<ll>& a) {
	pNode root = new Node(left, right);
	if (right - left == 1) {
		root->value[0] = a[left];
		return root;
	}
	root->child_left = build(left, (left + right) / 2, a);
	root->child_right = build((left + right) / 2, right, a);
	merge(root->child_left->value, root->child_right->value, root->value);
	return root;
}

ll get(pNode root, ll left_, ll right_) {
	if (root->left >= right_ || root->right <= left_) {
		return 0;
	}
	if (root->left >= left_ && root->right <= right_) {
		if (root->value.back() >= right_) {
			return  root->value.size();
		}
		ll left = -1;
		ll right = root->value.size();
		while (right - left > 1) {
			ll mid = (left + right) / 2;
			if (root->value[mid] >= right_) {
				left = mid;
			}
			else {
				right = mid;
			}
		}
		return right;
	}
	return get(root->child_left, left_, right_) + get(root->child_right, left_, right_);
}

inline void solve() {
	ll n, m;
	cin >> n >> m;
	vector<ll> a(m);
	vector<ll> b(n);
	for (ll i = 0; i < m; ++i) {
		cin >> a[i];
	}
	for (ll i = 0; i < n; ++i) {
		cin >> b[i];
	}
	reverse(b.begin(), b.end());
	vector<ll> used(n + 1);
	vector<ll> d;
	for (ll i = 0; i < m; ++i) {
		if (used[a[i]]) {
			d.emplace_back(a[i]);
		}
		else {
			while (b.back() != a[i]) {
				used[b.back()] = 1;
				d.emplace_back(b.back());
				b.pop_back();
			}
			used[b.back()] = 1;
			d.emplace_back(b.back());
			b.pop_back();
		}
	}
	vector<ll> id(n + 1, -1);
	vector<ll> res(d.size());
	vector<ll> next(d.size());
	vector<Question> q;
	for (ll i = d.size() - 1; i >= 0; --i) {
		if (id[d[i]] == -1) {
			res[i] = n;
			next[i] = d.size() + 100;
		}
		else {
			q.emplace_back(i, id[d[i]], i);
			next[i] = id[d[i]];
		}
		id[d[i]] = i;
	}
	pNode root = build(0, next.size(), next);
	for (auto i : q) {
		res[i.index] = get(root, i.left, i.right);
	}
	cout << res.size() << endl;
	for (ll i : res) {
		cout << i << " ";
	}
}

int main() {
	start();
	solve();
	return 0;
}
