#include <fstream>
#include <algorithm>
#include <cstdio>
#include <cmath>
#include <map>
#include <set>
#include <queue>
#include <string>
#include <utility>
#include <cassert>
#include <ctime>
#include <vector>
#include <deque>

#pragma warning(disable: 4996)

using namespace std;

#include <iostream>
//const string FILENAME = "test";
//ifstream cin(FILENAME + ".in");
//ofstream cout(FILENAME + ".out");

template<class C> void chkmin(C& a, const C& b) { if (a > b) a = b; }
template<class C> void chkmax(C& a, const C& b) { if (a < b) a = b; }

typedef long long ll;
typedef long double ld;

ll myRand() {
	return (ll)rand() ^ ((ll)rand() << 32ll);
}

struct Node {
	int val;
	int size;
	int ind;
	int imod;
	ll y;
	Node* left;
	Node* right;
	Node* parent;

	Node(int val, int ind) : val(val), size(1),
		ind(ind), imod(0),
		y(myRand()),
		left(NULL), right(NULL), parent(NULL) {}
};

int size(Node* t) { return t ? t->size : 0; }
int ind(Node* t) { return t ? t->ind : -1; }
int imod(Node* t) { return t ? t->imod : 0; }

void setParent(Node* t, Node* p) {
	if (t != NULL) t->parent = p;
}

void update(Node* t) {
	t->size = size(t->left) + size(t->right) + 1;
	setParent(t->left, t);
	setParent(t->right, t);
}

void applyMod(Node* t, int c) {
	if (t == NULL) return;
	t->ind += c;
	t->imod += c;
}

void push(Node* t) {
	applyMod(t->left, t->imod);
	applyMod(t->right, t->imod);
	t->imod = NULL;
}

int CalcInd(Node* t) {
	assert(t != NULL);
	int res = t->ind;
	while (t->parent != NULL) {
		t = t->parent;
		res += t->imod;
	}
	return res;
}

Node* Merge(Node* l, Node* r) {
	if (l == NULL) return r;
	if (r == NULL) return l;
	push(l);
	push(r);
	if (l->y < r->y) {
		l->right = Merge(l->right, r);
		update(l);
		return l;
	} else {
		r->left = Merge(l, r->left);
		update(r);
		return r;
	}
}

typedef pair<Node*, Node*> NodePair;

NodePair Split(Node* t, int k) {
	if (t == NULL) return NodePair(NULL, NULL);
	push(t);
	NodePair p;
	int lsize = size(t->left);
	if (lsize < k) {
		p = Split(t->right, k - lsize - 1);
		t->right = p.first;
		p.first = t;
	} else {
		p = Split(t->left, k);
		t->left = p.second;
		p.second = t;
	}
	update(t);
	return p;
}

Node* GetFirst(Node* t) {
	while (t->left != NULL)
		t = t->left;
	return t;
}

Node* Shift(Node* t, int i) {
	NodePair p = Split(t, 1);
	Node* a = p.first;
	Node* b = p.second;
	p = Split(b, i);
	b = p.first;
	Node* c = p.second;
	applyMod(a, i);
	applyMod(b, -1);
	return Merge(Merge(b, a), c);
}





//const int MAXN = 1 << 19;
const int MAXN = 3e5 + 7;
const int SHIFT = MAXN;

int RMQ[MAXN + SHIFT];
Node* inTreap[MAXN];

int Max(int i, int j) {
	if (i == 0) return j;
	if (j == 0) return i;
	if (CalcInd(inTreap[i]) < CalcInd(inTreap[j]))
		return j;
	return i;
}

void Init() {
	for (int i = MAXN - 1; i; --i) {
		RMQ[i] = Max(RMQ[2 * i], RMQ[2 * i + 1]);
	}
}

// 
int Get(int l, int r) {
	--r;
	l += SHIFT;
	r += SHIFT;
	int res = 0;
	while (l <= r) {
		if (l & 1)
			res = Max(res, RMQ[l]);
		l = (l + 1) / 2;
		if ((r & 1) == 0)
			res = Max(res, RMQ[r]);
		r = (r - 1) / 2;
	}
	return res;
}

void UpdateRMQ(int i) {
	i += SHIFT;
	i /= 2;
	while (i) {
		RMQ[i] = Max(RMQ[2 * i], RMQ[2 * i + 1]);
		i /= 2;
	}
}

int firstIn[MAXN];
int lastIn[MAXN];

int nxt[MAXN];
int give[MAXN];
vector<int> res;


int main() {
	srand(time(0));
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);
	int n, m;
	cin >> n >> m;
	for (int j = 0; j < m; ++j) {
		cin >> RMQ[j + SHIFT];
	}
	Node* t = 0;
	for (int i = 0; i < n; ++i) {
		firstIn[i + 1] = m;
		lastIn[i + 1] = -1;
		int val;
		cin >> val;
		Node* c = new Node(val, i);
		inTreap[val] = c;
		t = Merge(t, c);
	}
	for (int j = m - 1; j >= 0; --j) {
		nxt[j] = firstIn[RMQ[j + SHIFT]];
		firstIn[RMQ[j + SHIFT]] = j;
	}
	Init();
	for (int j = 0; j < m; ++j) {
		while (GetFirst(t)->val != RMQ[j + SHIFT]) {
			int item = GetFirst(t)->val;
			int lst = lastIn[item];
			int cNxt = lst == -1 ? firstIn[item] : nxt[lst];
			assert(j < cNxt);
			int ind = CalcInd(inTreap[Get(j, cNxt)]);
			t = Shift(t, ind);
			UpdateRMQ(cNxt);
			res.push_back(ind);
			//cout << ind << '\n';
		}
		int ind = 0;
		if (j + 1 < nxt[j]) {
			ind = CalcInd(inTreap[Get(j + 1, nxt[j])]);
			t = Shift(t, ind);
		}
		UpdateRMQ(nxt[j]);
		res.push_back(ind);
		//cout << ind << '\n';
		lastIn[RMQ[j + SHIFT]] = j;
		//cout << "-- DONE --\n";
	}


	cout << res.size() << '\n';
	for (int c : res) {
		cout << c + 1 << ' ';
	}
	cout << '\n';
}

