#include <iostream>
#include <vector>
#include <set>
#include <algorithm>

using namespace std;

struct tree
{
    int x;
    int y;
    tree* parent = NULL;
    tree* left = NULL;
    tree* right = NULL;
    int node_sz = 1;
    tree(int x) : x(x)
    {
        y = rand();
    }
};

void print_tree(tree* x, int tabs = 0)
{
    if(x == NULL)
        return;
    print_tree(x->left, tabs + 4);
    cout << string(tabs, ' ') << x->x << endl;
    print_tree(x->right, tabs + 4);
}

void set_parent(tree* x, tree* y)
{
    if(x != NULL)
        x->parent = y;
}

int get_sz(tree* x)
{
    if(x == NULL)
        return 0;
    return x->node_sz;
}

int get_idx(tree* t)
{
    tree* prev = (tree*)(intptr_t)-1;
    int ans = 0;
    while(t != NULL)
    {
        if(prev == t->left)
            ans++;
        else
            ans += get_sz(t->left);
        prev = t;
        t = t->parent;
    }
    return ans;
}

tree* pop_leftmost(tree*& x)
{
    if(x->node_sz == 1)
    {
        tree* ans = x;
        x = NULL;
        set_parent(ans, NULL);
        return ans;
    }
    else if(x->left != NULL)
    {
        x->node_sz--;
        return pop_leftmost(x->left);
    }
    else
    {
        tree* ans = x;
        x = x->right;
        set_parent(x, ans->parent);
        ans->right = NULL;
        ans->node_sz = 1;
        return ans;
    }
}

void split(tree* x, int i, tree*& a, tree*& b)
{
/*  cout << "splitting " << i << endl;
    print_tree(x);
    cout << "!!!!!!!!!\n";*/
    if(x == NULL)
    {
        a = NULL;
        b = NULL;
    }
    else if(get_sz(x->left) < i)
    {
//      cout << "to left\n";
        a = x;
        split(a->right, i - get_sz(a->left) - 1, a->right, b);
        set_parent(a->right, a);
        a->node_sz = 1 + get_sz(a->left) + get_sz(a->right);
    }
    else
    {
//      cout << "to right\n";
        b = x;
        split(b->left, i, a, b->left);
        set_parent(b->left, b);
        b->node_sz = 1 + get_sz(b->left) + get_sz(b->right);
    }
/*  cout << "returning from split\n";
    set_parent(a, NULL);
    cout << "!!!!!!!!! !!!! !!!!!\n";
    set_parent(b, NULL);
    cout << "!!!!!!!!! !!!! !!!!!\n";*/
}

tree* merge(tree* a, tree* b)
{
    if(a == NULL)
        return b;
    if(b == NULL)
        return a;
    if(a->y < b->y)
    {
        a->right = merge(a->right, b);
        set_parent(a->right, a);
        a->node_sz = 1 + get_sz(a->left) + get_sz(a->right);
        return a;
    }
    else
    {
        b->left = merge(a, b->left);
        set_parent(b->left, b);
        b->node_sz = 1 + get_sz(b->left) + get_sz(b->right);
        return b;
    }
}

int main()
{
    srand(179179179);
    int n, m;
    cin >> n >> m;
    long long queue_idx[n];
    for(int i = 0; i < n; i++)
        queue_idx[i] = -1;
    int arr1[m], arr2[n], blya[n];
    for(int i = 0; i < m; i++)
    {
        cin >> arr1[i];
        arr1[i]--;
    }
    for(int i = 0; i < n; i++)
    {
        cin >> arr2[i];
        arr2[i]--;
    }
    int stack_ptr = 0;
    vector<int> answers;
    for(int i = 0; i < m; i++)
    {
        int j = i;
        while(j < m && queue_idx[arr1[j]] >= 0)
            j++;
        set<int> ss;
        pair<int, int> arr[j - i];
        for(int k = i; k < j; k++)
            arr[k - i] = make_pair(queue_idx[arr1[k]], k);
        sort(arr, arr + j - i);
        set<int> qq;
        qq.insert(j);
        for(pair<int, int> k : arr)
        {
            if(ss.find(k.first) != ss.end())
                continue;
            ss.insert(k.first);
            int idx = k.second;
            int other = *qq.lower_bound(idx);
            qq.insert(idx);
            if(other != m)
                answers[queue_idx[arr1[idx]]] = arr1[other];
        }
        for(int k = i; k < j; k++)
            blya[arr1[k]] = -1;
        int prev_occur[j - i];
        for(int k = j - 1; k >= i; k--)
        {
            prev_occur[k - i] = blya[arr1[k]];
            blya[arr1[k]] = k;
        }
        int i0 = i;
        set<int> hards;
        for(int k = i; k < j; k++)
            if(prev_occur[k - i0] < 0)
                hards.insert(k);
        while(i < j)
        {
            if(prev_occur[i - i0] < 0)
            {
                answers.push_back(-1);
                queue_idx[arr1[i]] = answers.size() - 1;
            }
            else
            {
                int next_occur = *hards.lower_bound(prev_occur[i - i0]);
                answers.push_back(arr1[next_occur]);
                hards.insert(prev_occur[i]);
            }
            i++;
        }
        while(i < m)
        {
            int cur = arr2[stack_ptr++];
            answers.push_back(-1);
            queue_idx[cur] = answers.size() - 1;
            if(cur != arr1[i])
                continue;
            break;
        }
    }
    tree* tr = NULL;
    tree* nodes[n];
    for(int i = 0; i < n; i++)
        tr = merge(tr, nodes[arr2[i]] = new tree(arr2[i]));
    cout << answers.size() << endl;
    //goto output;
    for(int& i : answers)
    {
/*      cout << "######################### " << i << endl;
        print_tree(tr);
        cout << "#########################\n";*/
        tree* cur = pop_leftmost(tr);
        if(i >= 0)
        {
            tree* a;
            tree* b;
            split(tr, get_idx(nodes[i]), a, b);
            i = get_sz(a) + 1;
            tr = merge(a, merge(cur, b));
        }
        else
        {
            i = n;
            tr = merge(tr, cur);
        }
    }
output:
    if(!answers.empty())
    {
        cout << answers[0];
        for(int i = 1; i < answers.size(); i++)
            cout << ' ' << answers[i];
    }
    cout << endl;
    return 0;
}
