#include <iostream>
#include <vector>
#include <list>
#include <algorithm>

using namespace std;

bool check_bno(int a, int b, int c)
{
    for(int i = 0; i < c; i++)
    {
        if(a % 3 == b % 3 && a % 3 != 1)
            return false;
        a /= 3;
        b /= 3;
    }
    return true;
}

struct edge
{
    edge* rev;
    list<edge*>* lst;
    list<edge*>::iterator it;
    int to;
    int pos;
};

void create_edge(list<edge*>* graph, int from, int to, int cap)
{
    edge* e1 = new edge;
    edge* e2 = new edge;
    e1->rev = e2;
    e2->rev = e1;
    e1->lst = graph + from;
    e2->lst = graph + to;
    e1->to = to;
    e2->to = from;
    e1->pos = 0;
    e2->pos = cap;
    graph[from].push_back(e1);
    e1->it = --graph[from].end();
}

int enlarge(list<edge*>* graph, vector<bool>& used, int i, int f, int limit = (1 << 31) - 1)
{
    if(limit == 0 || used[i])
        return 0;
    if(i == f)
        return limit;
    used[i] = true;
    int ans = 0;
    for(auto jit = graph[i].begin(); jit != graph[i].end(); ++jit)
    {
        edge* j = *jit;
        int cur = enlarge(graph, used, j->to, f, min(limit, j->rev->pos));
        if(cur)
        {
            if(j->pos == 0)
            {
                j->rev->lst->push_back(j->rev);
                j->rev->it = --j->rev->lst->end();
            }
            j->pos += cur;
            j->rev->pos -= cur;
            if(j->rev->pos == 0)
                j->lst->erase(jit++);
            ans += cur;
            limit -= cur;
        }
    }
    return ans;
}

int main()
{
    int n, k;
    cin >> n >> k;
    vector<pair<vector<int>, int> > data(n);
    for(int i = 0; i < n; i++)
    {
        data[i].first.resize(k);
        for(int j = 0; j < k; j++)
            cin >> data[i].first[j];
        data[i].second = i;
    }
    int bvalues[k];
    for(int i = 0; i < k; i++)
    {
        sort(data.begin(), data.end(), [&](const pair<vector<int>, int>& a, const pair<vector<int>, int>& b)
        {
            return a.first[i] < b.first[i];
        });
        bvalues[i] = data[n / 2].first[i] + data[n / 2 - 1].first[i];
    }
    sort(data.begin(), data.end(), [](const pair<vector<int>, int>& a, const pair<vector<int>, int>& b)
    {
        return a.second < b.second;
    });
    int types[n][k];
    for(int i = 0; i < n; i++)
        for(int j = 0; j < k; j++)
        {
            if(data[i].first[j] * 2 < bvalues[j])
                types[i][j] = 0;
            else if(data[i].first[j] * 2 > bvalues[j])
                types[i][j] = 2;
            else
                types[i][j] = 1;
        }
    int pow3[8] = {1, 3, 9, 27, 81, 243, 729, 2187};
    int m = pow3[k];
    vector<int> buckets[m];
    for(int i = 0; i < n; i++)
    {
        int bno = 0;
        for(int j = k - 1; j >= 0; j--)
            bno = 3 * bno + types[i][j];
        buckets[bno].push_back(i);
    }
    list<edge*> edges[m + 2];
    for(int i = 0; i < m; i += 3)
        if(!buckets[i].empty())
            for(int j = 0; j < m; j++)
                if(!buckets[j].empty() && check_bno(i, j, k))
                    create_edge(edges, i, j, 1000000000);
    for(int i = 0; i < m; i += 3)
        if(!buckets[i].empty())
            create_edge(edges, m, i, buckets[i].size());
    for(int i = 2; i < m; i += 3)
        if(!buckets[i].empty())
            create_edge(edges, i, m + 1, buckets[i].size());
    list<edge*> edges2[m + 2];
    for(int i = 0; i < m + 2; i++)
        edges2[i] = edges[i];
    while(true)
    {
        vector<bool> used(m + 2);
        if(!enlarge(edges, used, m, m + 1))
            break;
    }
    int ans = 0;
    for(edge* i : edges2[m])
        ans += i->pos;
    if(ans * 2 != n)
    {
        cout << "NO\n";
        return 0;
    }
    cout << "YES\n";
    for(int i = 0; i < m; i += 3)
        for(edge* e : edges2[i])
            if(e->to < m)
                for(int j = 0; j < e->pos; j++)
                {
                    cout << buckets[i].back() + 1 << ' ' << buckets[e->to].back() + 1 << endl;
                    buckets[i].pop_back();
                    buckets[e->to].pop_back();
                }
    return 0;
}
