#include <iostream>
#include <vector>
#include <algorithm>
#include <list>
#include <random>

typedef long long ll;

using namespace std;

const int INF = 1e9;
const int SINF = 1e8;

vector<pair<int, int>> tree;
vector<int> d;

void build(int t, int l, int r, vector<int> &a)
{
    if (l == r - 1)
    {
        tree[t] = {a[l], l};
        d[t] = 0;
        return;
    }

    int m = (l + r) / 2;
    build(2 * t, l, m, a);
    build(2 * t + 1, m, r, a);
    tree[t] = max(tree[2 * t], tree[2 * t + 1]);
}

void push(int t)
{
    tree[t].first += d[t];
    if (2 * t < tree.size())
    {
        d[2 * t] += d[t];
        d[2 * t + 1] += d[t];
    }
    d[t] = 0;
}

pair<int, int> get(int t, int l, int r, int L, int R)
{
    if (l >= r || L >= R || L < l || R > r)
        return {-INF, -INF};

    push(t);

    if (l == L && r == R)
        return tree[t];

    int m = (l + r) / 2;
    return max(get(2 * t, l, m, L, min(m, R)), get(2 * t + 1, m, r, max(L, m), R));
}

int get_elem(int t, int l, int r, int i)
{
    push(t);

    if (l == r - 1)
        return tree[t].first;

    int m = (l + r) / 2;
    if (i < m)
        return get_elem(2 * t, l, m, i);
    else
        return get_elem(2 * t + 1, m, r, i);
}

void update_range(int t, int l, int r, int L, int R, int x)
{
    if (l >= r || L >= R || L < l || R > r)
        return;

    push(t);

    if (l == L && r == R)
    {
        d[t] += x;
        push(t);
        return;
    }

    int m = (l + r) / 2;
    update_range(2 * t, l, m, L, min(m, R), x);
    update_range(2 * t + 1, m, r, max(L, m), R, x);
    push(2 * t);
    push(2 * t + 1);
    tree[t] = max(tree[2 * t], tree[2 * t + 1]);
}

int main()
{
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int n, m;
    cin >> n >> m;
    mt19937 gen(2007);
//
//    for (int c = 0; c <= 1000; c++)
//    {
        vector<int> orders(m);
        vector<vector<int>> fpos(n);
        for (int i = 0; i < m; i++)
        {
            cin >> orders[i];
            orders[i]--;
            //orders[i] = abs((int)gen()) % n;
            fpos[orders[i]].push_back(i);
        }

        vector<int> cards(n);
        //for (int i = 0; i < n; i++)
        //    cards[i] = i;
        //shuffle(cards.begin(), cards.end(), gen);

        list<int> cardslist;
        vector<int> positions(m, -INF);
        vector<list<int>::iterator> iterators(n);
        for (int i = 0; i < n; i++)
        {
            cin >> cards[i];
            cards[i]--;
            iterators[cards[i]] = cardslist.insert(cardslist.end(), cards[i]);
            if (!fpos[cards[i]].empty())
                positions[fpos[cards[i]][0]] = i;
        }

        tree.resize(4 * m, {-INF, -INF});
        d.resize(4 * m);
        for (int i = 0; i < 4 * m; i++)
        {
            tree[i] = {-INF, -INF};
            d[i] = 0;
        }
        build(1, 0, m, positions);
        int cur = 0;
        vector<int> ans;

        while (cur < m)
        {
            int x = *cardslist.begin();
            cardslist.erase(cardslist.begin());
            auto it = upper_bound(fpos[x].begin(), fpos[x].end(), cur);
            if (it == fpos[x].end())
            {
                iterators[x] = cardslist.insert(cardslist.end(), x);
                ans.push_back(n);
                update_range(1, 0, m, 0, m, -1);
            } else
            {
                pair<int, int> p;
                if (x == orders[cur])
                    p = get(1, 0, m, cur + 1, *it);
                else
                    p = get(1, 0, m, cur, *it);
                if (p.first <= -SINF)
                {
                    iterators[x] = cardslist.insert(cardslist.begin(), x);
                    ans.push_back(1);
                } else
                {
                    auto it1 = iterators[orders[p.second]];
                    it1++;
                    iterators[x] = cardslist.insert(it1, x);
                    ans.push_back(p.first + 1);
                }

                update_range(1, 0, m, *it, (*it) + 1, (*ans.rbegin() - 1) - get_elem(1, 0, m, *it));
                update_range(1, 0, m, cur, *it, -1);
                //update_range(1, 0, n, (*it) + 1, n, -1);
            }

            if (x == orders[cur])
                cur++;

//        for (int i = 0; i < m; i++)
//            cout << get(1, 0, m, i, i + 1).first << " ";
//        cout << endl;
        }

        cout << ans.size() << endl;
        for (int x : ans)
            cout << x << " ";


//        vector<int> cardsl = cards;
//        cur = 0;
//        int t = 0;
//        while (cur < m)
//        {
//            if (t >= ans.size())
//            {
//                for (int x : orders)
//                    cout << x << " ";
//                cout << endl;
//                for (int x : cards)
//                    cout << x << " ";
//                cout << endl;
//                cout << ans.size() << endl;
//                for (int x : ans)
//                    cout << x << " ";
//                return 0;
//            }
//            int x = cardsl[0];
//            cardsl.erase(cardsl.begin());
//            if (ans[t] > cardsl.size())
//                cardsl.push_back(x);
//            else
//                cardsl.insert(cardsl.begin() + ans[t] - 1, x);
//            if (x == orders[cur])
//                cur++;
//            t++;
//        }
//    }

    return 0;
}