#include <iostream>
#include <vector>
#include <algorithm>
#include <list>
#define _FORTIFY_SOURCE 0
#pragma GCC optimize("Ofast")
#pragma GCC optimize("no-stack-protector")
#pragma GCC optimize("unroll-loops")

typedef long long ll;

using namespace std;

const int INF = 1e9;
const int SINF = 1e8;

vector<pair<int, int>> tree;
vector<int> d;

void build(int t, int l, int r, vector<int> &a)
{
    if (l == r - 1)
    {
        tree[t] = {a[l], l};
        d[t] = 0;
        return;
    }

    int m = (l + r) / 2;
    build(2 * t, l, m, a);
    build(2 * t + 1, m, r, a);
    tree[t] = max(tree[2 * t], tree[2 * t + 1]);
}

void push(int t)
{
    tree[t].first += d[t];
    if (2 * t < tree.size())
    {
        d[2 * t] += d[t];
        d[2 * t + 1] += d[t];
    }
    d[t] = 0;
}

pair<int, int> get(int t, int l, int r, int L, int R)
{
    if (l >= r || L >= R || L < l || R > r)
        return {-INF, -INF};

    push(t);

    if (l == L && r == R)
        return tree[t];

    int m = (l + r) / 2;
    return max(get(2 * t, l, m, L, min(m, R)), get(2 * t + 1, m, r, max(L, m), R));
}

int get_elem(int t, int l, int r, int i)
{
    push(t);

    if (l == r - 1)
        return tree[t].first;

    int m = (l + r) / 2;
    if (i < m)
        return get_elem(2 * t, l, m, i);
    else
        return get_elem(2 * t + 1, m, r, i);
}

void update_range(int t, int l, int r, int L, int R, int x)
{
    if (l >= r || L >= R || L < l || R > r)
        return;

    push(t);

    if (l == L && r == R)
    {
        d[t] += x;
        push(t);
        return;
    }

    int m = (l + r) / 2;
    update_range(2 * t, l, m, L, min(m, R), x);
    update_range(2 * t + 1, m, r, max(L, m), R, x);
    push(2 * t);
    push(2 * t + 1);
    tree[t] = max(tree[2 * t], tree[2 * t + 1]);
}

int main()
{
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int n, m;
    cin >> n >> m;
    mt19937 gen(2007);

        vector<int> orders(m);
        vector<vector<int>> fpos(n);
        for (int i = 0; i < m; i++)
        {
            cin >> orders[i];
            orders[i]--;
            fpos[orders[i]].push_back(i);
        }

        vector<int> cards(n);

        list<int> cardslist;
        vector<int> positions(m, -INF);
        vector<list<int>::iterator> iterators(n);
        for (int i = 0; i < n; i++)
        {
            cin >> cards[i];
            cards[i]--;
            iterators[cards[i]] = cardslist.insert(cardslist.end(), cards[i]);
            if (!fpos[cards[i]].empty())
                positions[fpos[cards[i]][0]] = i;
        }

        tree.resize(4 * m, {-INF, -INF});
        d.resize(4 * m);
        build(1, 0, m, positions);
        int cur = 0;
        vector<int> ans;
        vector<int> fpc(n, 0);

        while (cur < m)
        {
            int x = *cardslist.begin();
            cardslist.erase(cardslist.begin());
            while (fpc[x] < fpos[x].size() && fpos[x][fpc[x]] <= cur)
                fpc[x]++;
            if (fpc[x] == fpos[x].size())
            {
                iterators[x] = cardslist.insert(cardslist.end(), x);
                ans.push_back(n);
                update_range(1, 0, m, 0, m, -1);
            }
            else
            {
                int it = fpos[x][fpc[x]];
                pair<int, int> p;
                if (x == orders[cur])
                    p = get(1, 0, m, cur + 1, it);
                else
                    p = get(1, 0, m, cur, it);
                if (p.first <= -SINF)
                {
                    iterators[x] = cardslist.insert(cardslist.begin(), x);
                    ans.push_back(1);
                } else
                {
                    auto it1 = iterators[orders[p.second]];
                    it1++;
                    iterators[x] = cardslist.insert(it1, x);
                    ans.push_back(p.first + 1);
                }

                update_range(1, 0, m, it, it + 1, (*ans.rbegin() - 1) - get_elem(1, 0, m, it));
                update_range(1, 0, m, cur, it, -1);
            }

            if (x == orders[cur])
            {
                cur++;
            }
        }

        cout << ans.size() << endl;
        for (int x : ans)
            cout << x << " ";

    return 0;
}