#include <stdio.h>
#include <vector>
#include <algorithm>
#include <queue>
#include <utility>

const int TYPES = 729, INF = 1e9;
int k, in[2][TYPES];

bool check(int u, int v) {
	for (int i = 0; i < k - 1; i++) {
		if (u % 3 != 1 && v % 3 != 1 && u % 3 == v % 3) {
			return false;
		}
		u /= 3;
		v /= 3;
	}
	return true;
}

struct edge {
	int c, f, v;
	edge(){}
	edge(int cc, int ff, int vv): c(cc), f(ff), v(vv) {}
};

std::vector<int> graph[2 * TYPES + 2];
std::vector<edge> e;

void add(int u, int v, int c) {
	int nu = (int)e.size() / 2;
	e.push_back(edge(c, 0, v));
	e.push_back(edge(0, 0, u));
	graph[u].push_back(2 * nu);
	graph[v].push_back(2 * nu + 1);
}

int d[2 * TYPES + 2], mi, ind[2 * TYPES + 2];
bool used[2 * TYPES + 2];

void bfs(int m) {
	for (int i = 0; i < 2 * TYPES + 2; i++) {
		d[i] = INF;
		used[i] = false;
		ind[i] = 0;
	}
	used[0] = true;
	std::queue<std::pair<int, int> > q;
	q.push(std::make_pair(0, 0));
	while (!q.empty()) {
		std::pair<int, int> p = q.front();
		q.pop();
		d[p.first] = p.second;
		for (int i = 0; i < (int)graph[p.first].size(); i++) {
			int en = graph[p.first][i];
			if (e[en].f + m <= e[en].c && !used[e[en].v]) {
				used[e[en].v] = true;
				q.push(std::make_pair(e[en].v, p.second + 1));
			}
		}
	}
}

bool dfs(int v, int fi, int m, int prm) {
	if (v == fi) {
		mi = prm;
		return true;
	}
	for (; ind[v] < (int)graph[v].size(); ind[v]++) {
		int en = graph[v][ind[v]];
		int u = e[en].v;
		if (e[en].f + m <= e[en].c && d[u] == d[v] + 1 && dfs(u, fi, m, std::min(prm, e[en].c - e[en].f))) {
			e[en].f += mi;
			e[en ^ 1].f -= mi;
			return true;
		}
	}
	return false;
}

void getflow(int cap) {
	while (cap > 0) {
		bfs(cap);
		while (dfs(0, 2 * TYPES + 1, cap, INF)){}
		cap /= 2;
	}
}

int main() {
	e.reserve(1065798);
	int n;
	scanf("%d%d", &n, &k);
	if (n > 10) {
		return 1;
	}
	int arr[n][k];
	int bo[k], bo1[k];
	for (int i = 0; i < n; i++) {
		for (int j = 0; j < k; j++) {
			scanf("%d", &arr[i][j]);
		}
	}
	for (int i = 0; i < k; i++) {
		int a[n];
		for (int j = 0; j < n; j++) {
			a[j] = arr[j][i];
		}
		std::nth_element(a, a + n / 2, a + n);
		bo[i] = a[n / 2];
		std::nth_element(a, a + n / 2 - 1, a + n);
		bo1[i] = a[n / 2 - 1];
	}
	std::vector<int> typ[2][TYPES];
	for (int i = 0; i < n; i++) {
		int ty = 0;
		for (int j = 1; j < k; j++) {
			int di = 0;
			if (arr[i][j] >= bo[j]) {
				di = 2;
			}
			if (arr[i][j] == bo[j] && bo[j] == bo1[j]) {
				di = 1;
			}
			ty *= 3;
			ty += di;
		}
		if (arr[i][0] < bo[0]) {
			typ[0][ty].push_back(i);
		} else {
			typ[1][ty].push_back(i);
		}
	}
	for (int i = 0; i < TYPES; i++) {
		add(0, i + 1, (int)typ[0][i].size());
		add(TYPES + i + 1, 2 * TYPES + 1, (int)typ[1][i].size());
	}
	for (int i = 0; i < TYPES; i++) {
		for (int j = 0; j < TYPES; j++) {
			if (check(i, j)) {
				add(i + 1, TYPES + j + 1, INF);
			}
		}
	}
	getflow(n / 2);
	int flow = 0;
	for (int en : graph[0]) {
		if (en % 2 == 0) {
			flow += e[en].f;
		}
	}
	if (flow != n / 2) {
		printf("NO");
		return 1;
	}
	printf("YES\n");
	int cnt = 0;
	bool used[n] = {};
	for (int i = 0; i < TYPES; i++) {
		for (int j : graph[i + 1]) {
			if (j % 2 == 0) {
				for (int ii = 0; ii < e[j].f; ii++) {
					int u = typ[0][i][in[0][i]++];
					int v = typ[1][e[j].v - TYPES - 1][in[1][e[j].v - TYPES - 1]++];
					printf("%d %d\n", u + 1, v + 1);
					for (int iii = 0; iii < k; iii++) {
						if ((arr[u][iii] < bo[iii] && arr[v][iii] < bo[iii]) || (arr[u][iii] > bo[iii] && arr[v][iii] > bo[iii])) {
							return 1;
						}
					}
					used[u] = true;
					used[v] = true;
					cnt++;
				}
			}
		}
	}
	for (int i = 0; i < n; i++) {
		if (!used[i]) {
			return 1;
		}
	}
	if (cnt != n / 2) {
		return 1;
	}
	return 0;
}
