#include <iostream>
#include <vector>
#include <algorithm>
#include <set>

using namespace std;

const int SZ = 3e5 + 10;

int n;
int arr[SZ];
vector<int> graph[SZ];
vector<int> rev_graph[SZ];

void read_all()
{
    set<pair<int, int> > st;
    cin >> n;
    for (int v = 1; v <= n; v++) {
        int to;
        cin >> to;
        arr[v] = to;
        if (to == -1 || st.count({v, to})) {
            arr[v] = -1;
            continue;
        }
        st.insert({to, v});
        rev_graph[to].push_back(v);
        graph[v].push_back(to);
        graph[to].push_back(v);
    }
}

bool theres_cycle(int v)
{
    set<int> st;
    while (v != -1 && !st.count(v)) {
        st.insert(v);
        v = arr[v];
    }
    if (v == -1)
        return false;
    return true;
}

pair<int, int> tree_action(int from, int v)
{
    vector<pair<int, int> > now;
    for (int to : graph[v]) {
        if (to == from)
            continue;
        now.push_back(tree_action(v, to));
    }
    pair<int, int> ans = {0, 1};
    for (auto h : now) {
        ans.first += max(h.first, h.second);
        ans.second += h.first;
    }
    return ans;
}

bool used[SZ];

pair<int, int> rev_tree_action(int v)
{
    vector<pair<int, int> > now;
    used[v] = true;
    for (int to : rev_graph[v]) {
        if (used[to])
            continue;
        now.push_back(rev_tree_action(to));
    }
    pair<int, int> ans = {0, 1};
    for (auto h : now) {
        ans.first += max(h.first, h.second);
        ans.second += h.first;
    }
    return ans;
}

vector<pair<int, int> > vect;
vector<int> cycle;

int get_mask_ans(int mask)
{
    vector<int> bits_now;
    for (int i = 0; i < (int)vect.size(); i++) {
        bits_now.push_back(mask & 1);
        mask >>= 1;
    }
    for (int i = 1; i < (int)bits_now.size(); i++) {
        if (bits_now[i] == 1 && bits_now[i - 1] == 1)
            return 0;
    }
    if (bits_now[0] == 1 && bits_now.back() == 1)
        return 0;
    int ans = 0;
    for (int i = 0; i < (int)vect.size(); i++) {
        if (bits_now[i] == 1)
            ans += vect[i].second;
        else
            ans += vect[i].first;
    }
    return ans;
}

int get_ans()
{
    int ans = 0;
    for (int mask = 0; mask < (1 << (int)vect.size()); mask++)
        ans = max(ans, get_mask_ans(mask));
    return ans;
}

void get_cycle(int v)
{
    set<int> st;
    while (!st.count(v)) {
        st.insert(v);
        v = arr[v];
    }
    while (cycle.empty() || cycle[0] != v)
        cycle.push_back(v);
}

int cycle_action(int v)
{
    cycle.clear();
    vect.clear();
    get_cycle(v);
    for (int u : cycle)
        used[u] = true;
    for (int u : cycle)
        vect.push_back(rev_tree_action(u));
    return get_ans();
}

bool comp_used[SZ];

void dfs(int v)
{
    comp_used[v] = true;
    for (int to : graph[v]) {
        if (!comp_used[to])
            dfs(to);
    }
}

int action(int v)
{
    dfs(v);
    if (theres_cycle(v))
        return cycle_action(v);
    pair<int, int> ans = tree_action(0, v);
    return max(ans.first, ans.second);
}

int stup_mask_action(int mask)
{
    set<int> st;
    for (int i = 1; i <= n; i++) {
        if (mask & 1)
            st.insert(i);
        mask >>= 1;
    }
    for (int v = 1; v <= n; v++) {
        for (int to : graph[v]) {
            if (st.count(v) && st.count(to))
                return 0;
        }
    }
    return st.size();
}

int stup_action()
{
    int ans = 0;
    for (int mask = 0; mask < (1 << n); mask++)
        ans = max(ans, stup_mask_action(mask));
    return ans;
}

signed main()
{
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    read_all();
    cout << stup_action();
    /*
    int res = 0;
    for (int i = 1; i <= n; i++) {
        if (!comp_used[i])
            res += action(i);
    }
    cout << res;
    */
    return 0;
}
