#include <iostream>
#include <vector>
#include <map>
#include <algorithm>

#define endl '\n'

using namespace std;

const int INF = 1e6;

struct node {
	int x, y;
	int to;
	int size;
	int min;
	node* left;
	node* right;
	node(int x, int to) : x(x), y(rand()), to(to), size(1), min(to), left(nullptr), right(nullptr) {}
};

int get(node* v) {
	if (!v) return 0;
	return v->size;
}

int getmin(node* v) {
	if (!v) return INF;
	return v->min;
}

void relax(node* v) {
	if (!v) return;
	v->size = get(v->left) + get(v->right) + 1;
	v->min = min(getmin(v->left), getmin(v->right));
	v->min = min(v->min, v->to);
}

node* merge(node* l, node* r) {
	if (!l) return r;
	if (!r) return l;

	if (l->y > r->y) {
		l->right = merge(l->right, r);
		relax(l);
		return l;
	}
	r->left = merge(l, r->left);
	relax(r);
	return r;
}

pair<node*, node*> split(node* v, int x) {
	if (!v) return { nullptr, nullptr };

	pair<node*, node*> t;
	if (get(v->left) + 1 > x) {
		t = split(v->left, x);
		v->left = t.second;
		relax(v);
		t.second = v;
	}
	else {
		t = split(v->right, x - get(v->left) - 1);
		v->right = t.first;
		relax(v);
		t.first = v;
	}
	return t;
}

node* insert(node* v, int i, int x, int to) {
	auto t = split(v, i);
	return merge(merge(t.first, new node(x, to)), t.second);
}

node* del(node* v, int i) {
	auto t = split(v, i);
	auto t2 = split(t.second, 1);
	return merge(t.first, t2.second);
}

void print(node* v) {
	if (!v) return;
	print(v->left);
	cout << v->x << " ";
	print(v->right);
	return;
}

int first(node* root) {
	auto t = split(root, 1);
	int ans = t.first->x;
	root = merge(t.first, t.second);
	return ans;
}

int getmin(node* root, int x) {
	auto t = split(root, x);
	int ans = getmin(t.second);
	root = merge(t.first, t.second);
	return ans;
}

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);

	int n, m;
	cin >> n >> m;

	vector<int> a(m);
	for (int i = 0; i < m; i++) {
		cin >> a[i];
	}

	vector<int> next(m);

	vector<int> last(n + 1, INF);
	for (int i = m - 1; i >= 0; i--) {
		next[i] = last[a[i]];
		last[a[i]] = i;
	}

	node* root = nullptr;
	vector<int> b(n);
	for (int i = 0; i < n; i++) {
		cin >> b[i];
	}

	vector<int> to(n + 1, INF);
	for (int i = 0; i < m; i++) {
		if (to[a[i]] == INF) {
			to[a[i]] = i;
		}
	}

	for (int i = 0; i < n; i++) {
		root = insert(root, i, b[i], to[b[i]]);
	}

	int i = 0;
	vector<int> ans;
	while (i < m) {
		int x = first(root);
		int ind = to[x];
		root = del(root, 0);
		if (ind == INF) {
			ind = n - 1;
			ans.push_back(n);
		}
		else {
			if (x == a[i]) {
				to[x] = next[ind];
				i++;
			}
			if (to[x] == INF) {
				ind = n - 2;
			}
			else {
				int l = 0;
				int r = n - 1;
				while (l + 1 < r) {
					int m = (l + r) / 2;
					if (getmin(root, m) <= to[x]) {
						l = m;
					}
					else {
						r = m;
					}
				}
				ind = l;
				if (getmin(root, l) > to[x]) {
					ind--;
				}
			}
			ans.push_back(ind + 2);
		}
		root = insert(root, ind + 1, x, to[x]);
		//print(root);
		//cout << endl;
	}

	cout << ans.size() << endl;
	for (auto i : ans) {
		cout << i << " ";
	}
}