#include <iostream>
#include <vector>
#include <algorithm>
#include <string>
#include <random>


using namespace std;


const int MAXN = (int)3e5;
const int INF = (int)1e6;


class Treap {
    struct Node {
        int x, npos, minnpos, sz;

        Node(int x, int npos) : x(x), npos(npos), minnpos(npos), sz(1) {};
    };

    vector<Node> ns = { {0, 0} };
    vector<int> Ls = { 0 }, Rs = { 0 };

    int new_node(int x, int npos) {
        ns.emplace_back(x, npos);
        Ls.push_back(0);
        Rs.push_back(0);

        return ns.size() - 1;
    }

    inline int get_sz(int N) {
        if (!N) {
            return 0;
        }

        return ns[N].sz;
    }

    inline int get_minpos(int N) {
        if (!N) {
            return INF;
        }

        return ns[N].minnpos;
    }

    inline void update(int N) {
        if (!N) {
            return;
        }

        ns[N].sz = get_sz(Ls[N]) + get_sz(Rs[N]) + 1;
        ns[N].minnpos = min({ ns[N].npos, get_minpos(Ls[N]), get_minpos(Rs[N]) });
    }

    int merge(int L, int R) {
        if (!L) {
            return R;
        }

        if (!R) {
            return L;
        }

        int T;

        if (rand() % 2) {
            Rs[L] = merge(Rs[L], R);

            T = L;
        } else {
            Ls[R] = merge(L, Ls[R]);

            T = R;
        }

        update(T);

        return T;
    }

    void split(int T, int x, int &L, int &R) {
        if (!T) {
            L = R = 0;

            return;
        }

        int ls = get_sz(Ls[T]);

        if (ls < x) {
            split(Rs[T], x - ls - 1, Rs[T], R);

            L = T;
        } else {
            split(Ls[T], x, L, Ls[T]);

            R = T;
        }

        update(T);
    }

    int root = 0;

public:
    Treap() {};

    void insert(int x, int npos, int i) {
        int L = 0, R = 0;

        split(root, i, L, R);

        root = merge(merge(L, new_node(x, npos)), R);
    }

    int get_front() {
        int N = root;

        while (Ls[N]) {
            N = Ls[N];
        }

        return ns[N].x;
    }

    void pop_front() {
        int L = 0, R = 0;

        split(root, 1, L, R);

        root = R;
    }

    int get_inpos(int npos) {
        int N = root;

        int i = 0;

        while (get_sz(N) > 0) {
            if (get_minpos(Rs[N]) > npos) {
                if (ns[N].npos < npos) {
                    return i + get_sz(Ls[N]) + 1;
                }

                N = Ls[N];
            } else {
                i += get_sz(Ls[N]) + 1;

                N = Rs[N];
            }
        }

        return i;
    }
};


int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);

    int n, m;
    cin >> n >> m;

    vector<int> a(m);
    for (int i = 0; i < m; ++i) {
        cin >> a[i];

        --a[i];
    }

    vector<int> b(n);
    for (int i = 0; i < n; ++i) {
        cin >> b[i];

        --b[i];
    }

    vector<int> npos(n, INF);
    vector<int> next(m, INF);
    vector<int> last(n, -1);
    for (int i = 0; i < m; ++i) {
        if (last[a[i]] != -1) {
            next[last[a[i]]] = i;
        } else {
            npos[a[i]] = i;
        }

        last[a[i]] = i;
    }

    Treap tree;
    for (int i = 0; i < n; ++i) {
        tree.insert(b[i], npos[b[i]], i);
    }

    vector<int> act;

    for (int i = 0; i < m; ++i) {
        int cur = tree.get_front();

        while (cur != a[i]) {
            tree.pop_front();

            int k = tree.get_inpos(npos[cur]);

            tree.insert(cur, npos[cur], k);

            act.push_back(k + 1);

            cur = tree.get_front();
        }

        npos[cur] = next[i];

        tree.pop_front();

        int k = tree.get_inpos(npos[cur]);

        tree.insert(cur, npos[cur], k);

        act.push_back(k + 1);
    }

    cout << act.size() << '\n';
    for (int x : act) {
        cout << x << ' ';
    }

    return 0;
}