#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

typedef long long ll;
typedef pair<int, int> pii;

template<class T>
istream& operator>>(istream &in, vector<T> &ar) {
    for (int i = 0; i < ar.size(); ++i)
        in >> ar[i];
    return in;
}

template<class T>
ostream& operator<<(ostream &out, vector<T> &ar) {
    for (T x : ar)
        out << x << ' ';
    return out;
}

typedef vector<vector<int>> Graph;

int find_cycle(int x, vector<int> &color, Graph &g, vector<int> &cycle_out, int prev = -1) {
    color[x] = 1;
    for (int v : g[x]) {
        if (v == prev)
            continue;
        if (color[v] == 1) {
            cycle_out.push_back(x);
            color[x] = 3;
            return v;
        }
        if (color[v] == 2)
            continue;
        int t = find_cycle(v, color, g, cycle_out, x);
        if (t == -1)
            continue;
        if (t == g.size())
            return g.size();
        cycle_out.push_back(x);
        color[x] = 3;
        if (x == t)
            return g.size();
        return t;
    }
    color[x] = 2;
    return -1;
}

pii solve_tree(int x, vector<int> &color, Graph &g, int prev = -1) {
    int in = 1, out = 0;
    color[x] = 3;
    for (int v : g[x]) {
        if (color[v] == 3)
            continue;
        pii t = solve_tree(v, color, g, x);
        in += t.second;
        out += max(t.first, t.second);
    }
    return {in, out};
}

int solve_component(int x, vector<int> &color, Graph &g) {
    vector<int> cycle;
    find_cycle(x, color, g, cycle);
    if (cycle.size() == 0) {
        pii t = solve_tree(x, color, g);
        return max(t.first, t.second);
    }
    vector<pii> d(cycle.size());
    for (int i = 0; i < cycle.size(); ++i)
        d[i] = solve_tree(cycle[i], color, g);
    vector<int> dii(cycle.size()), dio(cycle.size()), doi(cycle.size()), doo(cycle.size());
    dii[0] = d[0].first;
    dio[0] = 0;
    doi[0] = 0;
    doo[0] = d[0].second;
    for (int i = 1; i < cycle.size(); ++i) {
        dio[i] = d[i].second + max(dio[i - 1], dii[i - 1]);
        dii[i] = d[i].first + dio[i - 1];
        doi[i] = d[i].first + doo[i - 1];
        doo[i] = d[i].second + max(doi[i - 1], doo[i - 1]);
    }
    return max(doi[cycle.size() - 1], max(dio[cycle.size() - 1], doo[cycle.size() - 1]));
}

int main() {
    //ios::sync_with_stdio(0);
    //cin.tie(0);
    int n;
    cin >> n;
    vector<int> a(n);
    cin >> a;
    Graph g(n);
    for (int i = 0; i < n; ++i) {
        if (a[i] == -1)
            continue;
        g[i].push_back(a[i] - 1);
        g[a[i] - 1].push_back(i);
    }
    vector<int> color(n, 0);
    int ans = 0;
    for (int i = 0; i < n; ++i) {
        if (!color[i])
            ans += solve_component(i, color, g);
    }
    cout << ans << '\n';
}
